library(cowplot)
library(data.table)
library(plyr)
library(dplyr)
library(reshape2)
library(ggplot2)
library(ggpubr)
library(gridExtra)
library(ggsci)
library(ggrepel)
library(viridis) 
library(ggpointdensity) 
library(lme4)
library(nlme)
library(lmodel2)
library(RColorBrewer)
library(extrafont)
library(lmodel2)
library(patchwork)
library(ggthemes)
library(cowplot)
library(plotrix)
library(ggsignif)
library(scales)
library(doBy)

#####Calculate st using the anomaly value and then scale in the linear
#####pep725 ######
pep <- fread('pep_climate.csv')
pep$sp <- factor(pep$sp, labels = c('Aesculus hippocastanum',
                                    'Alnus glutinosa','Betula pendula',
                                    'Fagus sylvatica','Fraxinus excelsior',
                                    'Quercus robur','Ribes grossularia',
                                    'Tilia cordata','Tilia platyphyllos'))

pep$suc <- ifelse(pep$sp %in% c('Aesculus hippocastanum', 'Alnus glutinosa', 
                                'Betula pendula','Ribes grossularia'), 'early', 'late')
ddply(pep[, c('suc', 'sp', 'bbch11')], .(suc, sp), summarise, d = min(bbch11))

n <- pep %>% 
  ddply(., .(pep_id, sp, lon, lat, alt), summarise, vy = length(unique(year)))

pep1 <- pep %>% 
  ddply(., .(pep_id, sp), mutate, msos = mean(bbch11), mt = mean(tmean)) %>% 
  mutate(., sos = bbch11-msos, tem = tmean-mt)

pep_lm <- function(x){
  a = as.data.frame(lm(scales::rescale(sos)~scales::rescale(tem), data = x)$coef[2])
  colnames(a) <- 'st'
  return(a)
}
# pept <- ddply(pep1, .(sp), summarise, t = mean(mt))
# pept
pep_res <- ddply(pep1, .(pep_id, lon, lat, alt, sp, suc), pep_lm)

ddply(pep_res, .(suc), summarise, mst = mean(st), ste= plotrix::std.error(st), 
      u = length(unique(pep_id)), 
      lc = Rmisc::CI(st, ci = 0.95)[2], uc = Rmisc::CI(st, ci = 0.95)[1])


####fig2a histgram
ggplot()+
  geom_histogram(data= pep_res,aes(x=st ,y= ..count..), 
                 binwidth = 0.04, size = 1, color = 'black', fill = '#96C9C2')+
  geom_vline(xintercept = 0, col = 'grey20', size = 1.2, linetype = 2)+
  scale_y_continuous(expand = expansion(mult = c(0, 0)),limits = c(0,1000),breaks = seq(0,1000,250))+
  scale_x_continuous(expand = expansion(mult =c(0,0)),limits = c(-1, 0.5))+
  labs(title = 'PEP725', x = 'ST', y = 'Frequency', tag = 'a')+
  theme_classic()+
  theme(title = element_text(size = 22, color = "black", family = 'sans'),
        text = element_text(size = 18, color = "black", family = 'sans'),
        axis.text.x  = element_text(size = 20, color = "black", family = 'sans'),
        axis.text.y  = element_text(size = 20, color = "black", family = 'sans'),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))


###Multiple comparisons
###by species
library(multcompView)
library(tibble)
str(pep_res)
table(pep_res$sp)
a.aov <- aov(st~sp,data = pep_res)

tuk <- TukeyHSD(a.aov)
cld <- multcompLetters4(a.aov,tuk)
cld1 <- as.data.frame.list(cld$sp) %>% 
  dplyr::select(1) %>% 
  rownames_to_column('sp') 
pep_res1 <- left_join(pep_res, cld1, by = 'sp') 


### fig2b sp boxplot
 ggplot(pep_res1, aes(sp, st))+
  geom_boxplot(width = .6, size = 1, col = 'black', fill = '#96C9C2', outlier.shape = NA)+
  geom_hline(yintercept = 0, linetype = 2, colour = 'grey20', size = 1.2)+
  scale_y_continuous(expand = c(0, 0), limits = c(-1, .5), breaks = seq(-1,.5,.5))+
  geom_text(aes(label = Letters, y = quantile(st, probs = 0.95)+0.25), vjust = -0.5, size = 6)+
  labs(title = 'PEP725', x = 'Species', y = 'ST', tag = 'b')+
  theme_classic()+
  theme(title = element_text(size = 24, color = "black", family = 'sans'),
        text = element_text(size = 22, family = 'sans'),
        axis.text.x  = element_text(size = 22,color = "black",face="italic"), 
        axis.text.y  = element_text(size = 22,color = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))




###Multiple comparisons
###by succession types
library(multcompView)
library(tibble)
str(pep_res)
table(pep_res$suc)
a.aov <- aov(st~suc,data = pep_res)

tuk <- TukeyHSD(a.aov)
cld <- multcompLetters4(a.aov,tuk)
cld1 <- as.data.frame.list(cld$suc) %>% 
  dplyr::select(1) %>% 
  rownames_to_column('suc')
pep_res1 <- left_join(pep_res, cld1, by = 'suc') 

ggplot(pep_res1, aes(suc, st))+
  geom_boxplot(width = .5, size = 1, col = 'black', fill = '#96C9C2', outlier.shape = NA)+
  geom_hline(yintercept = 0, linetype = 2, colour = 'grey20', size = 1.2)+
  scale_y_continuous(expand = c(0, 0), limits = c(-1, .5), breaks = seq(-1,.5,.5))+
  labs(x = 'Successional Type', y = 'ST', tag = 'b')+
  theme_classic()+
  theme(title = element_text(size = 22, color = "black", family = 'sans'),
        text = element_text(size = 22, family = 'sans'),
        axis.text.x  = element_text(size = 22,color = "black"),
        axis.text.y  = element_text(size = 22,color = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))


##successional types histgram
ggplot()+
  geom_histogram(data=subset(pep_res1,suc == 'early'),
                 aes(x=st,y= ..count..,fill="A",color="A"),binwidth = 0.03)+
  geom_histogram(data=subset(pep_res1,suc == 'late'),
                 aes(x=st,y= ..count..,fill="B",color="B"),binwidth = 0.03,alpha=0.2)+
  labs(x='ST', y = 'Frequency', tag = 'a')+
  scale_y_continuous(expand = expansion(mult = c(0, 0)),limits = c(0,500),breaks = seq(0,500,100))+
  scale_x_continuous(expand = expansion(mult =c(0,0)),limits = c(-1.1, 0.6),breaks = seq(-1,0.5,0.5))+
  theme_classic()+
  scale_fill_manual(name=" ",values = c("A"='#96C9C2', "B"= '#E67474'))+
  scale_color_manual(values = c("A"='#96C9C2', "B"= '#E67474', alpha =.3))+
  theme(title = element_text(size = 22, color = "black", family = 'sans'),
        text = element_text(size = 22, family = 'sans'),
        axis.text.x  = element_text(size = 22,color = "black"),
        axis.text.y  = element_text(size = 22,color = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))+
  guides(fill = 'none', color = 'none')

#####phenocam ######
cam <- fread('phenocam_cliamte.csv')[, c(1:2,4:5,7,6,8:9)]


cam1 <- cam %>% 
  subset(., veg_type%in%c('DB', 'EN')) %>% 
  ddply(., .(site, veg_type), mutate, msos = mean(doy), mt = mean(tmean)) %>% 
  mutate(., sos = doy-msos, tem = tmean-mt)
ddply(cam1,.(veg_type), summarise, t = mean(tmean), e = std.error(tmean))
camcor <- unique(cam1[, c(1,5:6)])

cam1$veg_type <- factor(cam1$veg_type, labels = c('Deciduous Broadleaf Forest', 'Evergreen Needleleaf Forest'))
cam_res <- ddply(cam1, .(site, veg_type, lon, lat, elevation), pep_lm)
head(cam_res)

###Multiple comparisons
###by vegetation types
library(multcompView)
library(tibble)
a.aov <- aov(st~veg_type,data = cam_res)

tuk <- TukeyHSD(a.aov)
cld <- multcompLetters4(a.aov,tuk)
cld1 <- as.data.frame.list(cld$veg_type) %>% 
  dplyr::select(1) %>% 
  rownames_to_column('veg_type')
cam_res1 <- left_join(cam_res, cld1, by = 'veg_type') 


# fig3a  boxplot
ggplot(cam_res, aes(veg_type, st))+
  geom_boxplot(width = .6, size = 1, col = 'black', fill = '#96C9C2', outlier.shape = NA)+
  geom_hline(yintercept = 0, linetype = 2, colour = '#FFC0CB', size = 1.2)+
  scale_y_continuous(expand = c(0, 0), limits = c(-1, 1), breaks = seq(-1, 1, .5))+
  labs(title = 'PhenoCam', x = 'Vegetation Type', y = 'STmean',tag = 'c')+
  theme_classic()+
  theme(title = element_text(size = 22, family = 'sans'),
        text = element_text(size = 18, family = 'sans'),
        axis.text.x  = element_text(size = 20, colour = "black"), 
        axis.text.y  = element_text(size = 20, colour = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))




#####gimms ndvi3g #####
gim <- fread('gimmiData.csv')
gimcor <- unique(gim[, c(1:2)])
gim$BIOME_NAME1 <- factor(gim$BIOME_NAME, labels = c('NN', 'BFT', 'FGS', 'N/A', 'TBM', 'TCF', 'TGS', 'TSC', 'TSG', 'TSM', 'TUN'))
gim1 <- gim %>% 
  subset(., BIOME_NAME1%in%c('BFT', 'TBM','TCF')) %>% 
  ddply(., .(lon, lat, lat, BIOME_NAME), mutate, msos = mean(stsos), mt = mean(tmean)) %>% 
  mutate(., sos = stsos-msos, tem = tmean-mt)
ddply(gim1,.(BIOME_NAME1), summarise, t = mean(tmean), e = std.error(tmean))

gim_res <- ddply(gim1, .(lon, lat, alt, BIOME_NAME, BIOME_NAME1), pep_lm)

###mutiple comparisons
###by vegetation types
a.aov <- aov(st~BIOME_NAME1,data = gim_res)
tuk <- TukeyHSD(a.aov)
cld <- multcompLetters4(a.aov,tuk)
cld1 <- as.data.frame.list(cld$BIOME_NAME1) %>% 
  dplyr::select(1) %>% 
  rownames_to_column('BIOME_NAME1') 
gim_res1 <- left_join(gim_res, cld1, by = 'BIOME_NAME1') 


#fig3b biome boxplot
ggplot(gim_res, aes(x = BIOME_NAME, y = st))+
  geom_boxplot(width = .6, outlier.shape = NA, size = 1, col = 'black', fill =  '#96C9C2')+
  geom_hline(yintercept = 0, color ='#FFC0CB', size = 1.2, linetype = 'dashed')+
  scale_y_continuous(expand = c(0, 0), limits = c(-1, 1), breaks = seq(-1,1,.5))+
  labs(title = 'GIMMS NDVI3g', x = 'Vegetation Type', y = 'STmean', tag = 'd')+
  theme_classic()+
  theme(title = element_text(size = 22, family = 'sans'),
        text = element_text(size = 18, family = 'sans'),
        axis.text.x  = element_text(size = 20, colour = "black"), 
        axis.text.y  = element_text(size = 20, colour = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(4,24,4,4),"pt"))


#### fig s1####
###exclude models
##### This code hopes to analyze partial correlation through pep725 data
##### to exclude chilling, forcing, tmean in winter and spring
##### of growing season temperature on spring phenology
library(data.table)
library(plyr)
library(tidyverse)
library(lmerTest)
library(ppcor)
data_all <- fread('pcor_exclude_data.csv')
#####Partial correlation calculation#####
###Calculate the number of data bars corresponding to each species
n = ddply(data_all, .(sp), summarise, n = length(sp))

####### 1   exclude chilling and forcing   ######
pva <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('chilling', 'forcing')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}

###Calculation of partial correlations by species by site
sta <- ddply(data_all, .(pep_id, sp, lon, lat, alt), pva)###8022
sta <- subset(sta, pvalue<0.1)
ddply(sta[,c('sp', 'estimate', 'pvalue')], .(sp), summarise, estimate = median(estimate), pvalue = median(pvalue), n = length(sp))

###Calculate partial correlation by species
sta <- ddply(data_all, .(sp), pva)
sta <- plyr::join(sta, n)


####### 2   exclude climate factors, chilling and forcing ######
pva1 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu', 'chilling', 'forcing')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}

###Calculation of partial correlations by species by site
sta <- ddply(data_all, .(pep_id, sp, lon, lat, alt), pva1)
sta <- subset(sta, pvalue<0.1)
ddply(sta[,c('sp', 'estimate', 'pvalue')], .(sp), summarise, estimate = median(estimate), pvalue = median(pvalue), n = length(sp))

###Calculate partial correlation by species
sta <- ddply(data_all, .(sp), pva1)
sta <- plyr::join(sta, n)


####### 3   exclude climate factors ######
pva2 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}


###Calculation of partial correlations by species by site
sta <- ddply(data_all, .(pep_id, sp, lon, lat, alt), pva2)
sta <- subset(sta, pvalue<0.1)
ddply(sta[,c('sp', 'estimate', 'pvalue')], .(sp), summarise, estimate = median(estimate), pvalue = median(pvalue), n = length(sp))

###Calculate partial correlation by species
sta <- ddply(data_all, .(sp), pva2)
sta <- plyr::join(sta, n)

####### 4   exclude climate factors and  optimal-preseason temperature######
pva3 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu', 'opttmean')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}


###Calculation of partial correlations by species by site
sta <- ddply(data_all, .(pep_id, sp, lon, lat, alt), pva3)
sta <- subset(sta, pvalue<0.1)
ddply(sta[,c('sp', 'estimate', 'pvalue')], .(sp), summarise, estimate = median(estimate), pvalue = median(pvalue), n = length(sp))

###Calculate partial correlation by species
sta <- ddply(data_all, .(sp), pva3)
sta <- plyr::join(sta, n)


####### 5  Exclude multiple combinations of variables#######
### climate ###
pva4 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}
###climate chilling forcing ###
pva5 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu', 'chilling', 'forcing')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}

###climate eos chilling forcing###
pva6 <- function(x){
  pva <- ppcor::pcor.test(x$bbch11, x$tmean, x[, c('rad', 'precipitation', 'soil', 'hu', 'bbch94', 'chilling', 'forcing')])
  return(data.frame(cbind('estimate' = pva$estimate, 'pvalue' = pva$p.value)))
}

###Calculate partial correlation by species
###pva4
sta4 <- ddply(data_all, .(sp), pva4)

###pva5
sta5 <- ddply(data_all, .(sp), pva5)

###pva6
sta6 <- ddply(data_all, .(sp), pva6)

###Combine data from four cases####
result <- rbind(sta4, sta5, sta6)

library(ggsci)
####plot####
r1 <- ggplot(data = result,aes(x = type1, y = estimate))+
  geom_boxplot(size = 1.2, width = .6,fill = '#96C9C2', color = 'black')+
  #geom_jitter(position = position_nudge(x = 0), color = '#96C9C2',alpha = 0.5, size = 4)+
  geom_abline(slope = 0, intercept = 0, color = 'darkred', linetype = 'dashed', size = 1.2)+
  labs(y = 'Partial correlation coefficient', x = '')+
  scale_y_continuous(expand = c(0, 0), limits=c(-0.5,0.1), breaks = seq(-0.5,0,0.25))+
  theme_classic()+
  theme(text = element_text(size = 18, family = 'sans'),
        axis.title.y = element_text(size = 20, colour = "black",margin = margin(r = 5,unit = "pt"), face = "bold"),
        axis.text.x  = element_text(size = 20, colour = "black"), 
        axis.text.y  = element_text(size = 20, colour = "black",margin = margin(r = 10, unit = "pt")),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(32,24,32,24),"pt"),
        legend.position = 'none')

z1 <- fread('relative_importance.csv')

library(gg.gap)
z1$x1 <- factor(z1$x1, levels = c('Tmean', 'Radiation', 'SoilMoisture', 'Precipitation', 'Humidity'))
s<- ggplot(z1, aes(x = x1, y = y1, fill = x1))+
  geom_col(position = position_dodge(), col = 'black', size =1.5, width = .6, fill = '#96C9C2')+
  geom_label(aes(label = paste(round(z1$y1, 2))), size = 6, vjust=-0.25, fill = 'white',label.r = unit(0, 'pt'), label.size = 0)+
  labs(x = '', y = 'Relative Influence (%)')+
  theme_classic()+
  theme(text = element_text(size = 18, family = 'sans'),
        axis.title.y = element_text(size = 20, colour = "black",face = 'bold', margin = margin(r = 5,unit = "pt")),
        axis.text.x  = element_text(size = 20, colour = "black"), 
        axis.text.y  = element_text(size = 20, colour = "black",margin = margin(r = 10, unit = "pt")),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1))
s1 <- gg.gap(plot = s, segments = c(12, 75), tick_width = 5, rel_heights = c(0.5, 0.02, 0.25),
             ylim = c(0, 90))


library(ggpubr)
ggarrange(r1, s1, labels = c('a', 'b'),
          ncol = 2, nrow = 1, widths = c(1, 1.5))
####fluxnet data ####
d1 <- fread('fluxnet.csv')
flux_cor <- unique.data.frame(d1[, 3:4])

#Calculate correlation
##r
r=ddply(d1,.(site, lon.x, lat.x),function(x)cor(x$sos,x$gppmax))

######       Anomaly calculation     #####
d2 <- d1 %>% 
  ddply(., .(site), mutate, ms = mean(sos), mg = mean(gppmax), mt = mean(growt)) %>% 
  mutate(., dsos = sos-ms, dgppmax = gppmax-mg, dtmean = growt-mt)
# sos~gppmax ana
lms <- function(x){
  a = lm(scale(dsos)~scale(dgppmax), data=x)$coef[2]
  return(a)
}
d_res <- ddply(d2, .(site, lon.x, lat.x), lms)

# sos~tmean ana
lmt <- function(x){
  a = lm(scale(dsos)~scale(dtmean), data=x)$coef[2]
  return(a)
}
d_res1 <- ddply(d2, .(site, lon.x, lat.x), lmt)
ggplot(d_res1, aes(y = `scale(dtmean)`))+
  geom_boxplot()

###fig4a boxplot
ggplot(d_res, aes(y = `scale(dgppmax)`))+
  geom_boxplot(width = .3, size = 1, col = 'black', fill = '#96C9C2',
               outlier.color = 'black', outlier.size = 5, outlier.alpha = 0.3)+
  geom_hline(yintercept = 0, color ='grey20', size = 1.2, linetype = 'dashed')+
  scale_y_continuous(expand = c(0, 0), limits = c(-0.6, 0.6), breaks = seq(-0.5,0.5,0.25))+
  labs(x = ' ', y = 'Slope')+
  theme_classic()+
  theme(title = element_text(size = 24, family = 'sans'),
        text = element_text(size = 22, family = 'sans'),
        axis.text.x  = element_blank(),
        axis.text.y  = element_text(size = 22, colour = "black"),
        axis.ticks.length.y = unit(-0.2,"cm"),
        axis.ticks.length.x = unit(0,"cm"),
        axis.ticks = element_line(size = 1),
        axis.line = element_line(size = 1),
        plot.margin = unit(c(24,24,4,4),"pt"))


#####   The d1 data is used as the original data for the analysis of sem and randomforest#####
flux2 <- ct[,c(1:6,17:18,20:26)] %>% 
  subset(gppmax>0) %>% 
  ddply(., .(site), mutate, v=length(year)) %>% 
  subset(., v>= 10)

####sem Result analysis####
####piecewiseSEM
library(nlme)
library(r2mlm)
library(lubridate)
library(dplyr)
library(piecewiseSEM)

flux3 <- flux2 %>% 
  dplyr::select(., sos, gppmax,growgpp,growt,growrain,growco2,growradi,growvpd, growsoilw) %>% 
  scale() %>% 
  as.data.frame()
#mod1 gppmax
mod1 <- psem(
  lm(gppmax~growt+growrain+growradi+growco2+growsoilw,data = flux3),
  lm(sos~gppmax+growt+growrain+growradi+growco2+growsoilw, data = flux3),
  data = flux3
)


#mod2 gpp
mod2 <- psem(
  lm(growgpp~growt+growrain+growradi+growco2+growsoilw,data = flux3),
  lm(sos~growgpp+growt+growrain+growradi+growco2+growsoilw, data = flux3),
  data = flux3
)


####Random Forest Model Computation for Fluxnet####
# data:d1
require('pacman')
pacman::p_load(randomForest, caret, pROC, skimr)

flux3 <- flux2 %>% 
  dplyr::select(., sos, gppmax,growgpp,growt,growrain,growco2,growradi,growvpd, growsoilw) %>% 
  scale() %>% 
  as.data.frame()

set.seed(1234)
#gppmax
rf.train <- randomForest(sos~gppmax+growrain+growradi+growco2+growsoilw,
                         data = flux3, 
                         ntree = 1000, 
                         mtry = 4, 
                         importance = TRUE, 
                         na.action = na.omit) 

#tmean+gppmax
rf.train <- randomForest(sos~growgpp+growt+growrain+growradi+growsoilw+growco2,
                         data = flux3, 
                         replace=TRUE,
                         ntree = 1000, 
                         mtry = 5, 
                         importance = TRUE, 
                         na.action = na.omit) 
plot(rf.train, main = 'error & tree')
importance(rf.train)
varImpPlot(rf.train, main = 'importance 2', type = 2)

##igmt
igmt <- data.frame(a = c('gppmax', 'temperature', 'precipitation', 'radiation', 'soil water content', 'co2'),
                   b = c(60.24, 58.53, 44.56, 38.91, 35.33, 19.17))
igmt$a <- factor(igmt$a, levels = c('co2','soil water content', 'radiation', 'precipitation','temperature','gppmax'))
ggplot(igmt, aes(x = a, y = b))+
  geom_bar(stat = 'identity', fill = '#96C9C2', col = 'black', size =2.25, width = .75)+
  scale_y_continuous(expand = c(0,0), limits = c(0,80),breaks = seq(0, 80, 20))+
  geom_label(aes(label = b), size = 6, hjust = -0.25,
             fill = 'transparent', label.size = 0)+
  coord_flip()+
  labs(x = '', y = 'Relative Influence (%)', tag = 'b')+
  theme_classic()+
  theme(text = element_text(size = 22, family = 'sans'),
        axis.title.x = element_text(size = 24, colour = "black"),
        axis.title.y = element_text(size = 24, colour = "black"),
        axis.text.x  = element_text(size = 22, colour = "black"),
        axis.text.y  = element_text(size = 22, colour = "black"),
        axis.ticks.length.y = unit(0,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 2.25, color = 'black'),
        axis.line = element_line(size = 2.25),
        plot.margin = unit(c(4,24,4,4),"mm"))


##igt
igt <- data.frame(a = c('gpp','temperature', 'precipitation', 'radiation', 'soil water content', 'co2'),
                  b = c(68.01, 58.06, 42.47, 36.28, 34.09, 17.12))
igt$a <- factor(igt$a, levels = c('co2','soil water content', 'radiation', 'precipitation','temperature','gpp'))
ggplot(igt, aes(x = a, y = b))+
  geom_bar(stat = 'identity', fill = '#96C9C2', col = 'black', size =2.25, width = .75)+
  scale_y_continuous(expand = c(0,0), limits = c(0,80),breaks = seq(0, 80, 20))+
  geom_label(aes(label = b), size = 6, hjust = -0.25,
             fill = 'transparent', label.size = 0)+
  coord_flip()+
  labs(x = '', y = 'Relative Influence (%)', tag = 'b')+
  theme_classic()+
  theme(text = element_text(size = 22, family = 'sans'),
        axis.title.x = element_text(size = 24, colour = "black"),
        axis.title.y = element_text(size = 24, colour = "black"),
        axis.text.x  = element_text(size = 22, colour = "black"),
        axis.text.y  = element_text(size = 22, colour = "black"),
        axis.ticks.length.y = unit(0,"cm"),
        axis.ticks.length.x = unit(0.2,"cm"),
        axis.ticks = element_line(size = 2.25, color = 'black'),
        axis.line = element_line(size = 2.25),
        plot.margin = unit(c(4,24,4,4),"mm"))

