require(data.table)
require(plyr)
require(dplyr)
require(reshape2)
require(lubridate)
require(ggplot2)
require(ggpubr)
require(gridExtra)
require(ggsci)
require(ggrepel)
require(viridis) 
require(ggpointdensity) 
require(lme4)
require(lmodel2)
require(RColorBrewer)
require(extrafont)
require(lmodel2)
require(patchwork)
require(ggthemes)
require(cowplot)
require(plotrix)


###pep725 exclude models data####
##### This code hopes to analyze partial correlation through pep725 data
##### to exclude chilling forcing tmean in winter and spring
##### of growing season temperature on spring phenology
library(data.table)
library(plyr)
library(tidyverse)
library(lmerTest)
library(ppcor)

pep725Data <- fread('pep725Data.csv')
#####Data Analysis for Partial Correlation Computation
##all climate data
climatesall <- fread('climateData.csv')
##optimal preseason temperature
optimal <- fread('optimalTemperature.csv')
df1 <- left_join(pep725Data, climatesall, type = 'full') %>% left_join(.,optimal) %>% na.omit(.)
df2 <- ddply(df1, .(pep_id, sp), mutate, vy = length(unique(year)))
##select length of years more than 15
df3 <- subset(df2, vy >=15)
pcor <- ppcor::pcor.test(df3$bbch11, df3$tmean, 
                         df3[, c('radiation', 'precipitation', 'soil', 'humidity', 'optTmean')])

#####chilling forcing calculation####
## function of chilling forcing
chill_fun <-  function(x){
  m <- as.numeric(x$tg < 5)
  ##tmean<5℃
  chilling <- sum(m)
  return(as.data.frame(chilling))
}

force_fun <- function(x){
  forcing = data.frame()
  for(i in 1:length(x$tg)){
    if(x$tg[i]>=5){
      ##tmean>5℃
      m =x$tg[i]-5
      forcing= sum(forcing+m)
    }
    else i+1
  }
  return(as.data.frame(forcing))
}

pep_new <- unique(df3[, c('pep_id', 'sp', 'lon', 'lat', 'alt', 'year', 'bbch11')])
###climate data 
cli <- fread('climate.csv')[, c('pep_id', 'tg', 'year', 'month', 'day')]

###climate choose from 11.1 of previous year to sos of current year
cli11 <- subset(cli, month %in% c(11:12))
cli11$year <- cli11$year+1
dt1 <- data.table(cli11, key =c("pep_id","year"))
dt2 <- data.table(pep_new, key =c("pep_id","year"))
cli11<- dt1[dt2,allow.cartesian=TRUE]

clisos <- subset(cli, month %in% c(1:6))
dt1 <- data.table(clisos, key =c("pep_id","year"))
dt2 <- data.table(pep_new, key =c("pep_id","year"))
clisos<- dt1[dt2,allow.cartesian=TRUE]

clisos$doy <- yday(as.Date(with(clisos,paste(year, month, day, sep = '-'), '%Y-%m-%d')))
clisos <- subset(clisos, doy<= bbch11)

###combine climate data and phenology data 
cli <- na.omit(rbind(cli11, clisos[, -'doy']))
###calculate chilling and forcing
chill <- ddply(cli, .(pep_id, lon, lat, alt, sp, year), chill_fun)
force <- ddply(cli, .(pep_id, lon, lat, alt, sp, year), force_fun)
fix <- cli[,by = .(pep_id, lon, lat, alt, sp, year), .(fixtmean = mean(tg))]

###combine growing season data and chilling, forcing data 
dt1 <- data.table(df3, key =c("pep_id","lon", "lat", "alt", "sp","year"))
dt2 <- data.table(chill,  key =c("pep_id","lon", "lat", "alt", "sp","year"))
data_all<- dt1[dt2,allow.cartesian=TRUE]

dt1 <- data.table(data_all, key =c("pep_id","lon", "lat", "alt", "sp","year"))
dt2 <- data.table(force,  key =c("pep_id","lon", "lat", "alt", "sp","year"))
data_all<- dt1[dt2,allow.cartesian=TRUE]

dt1 <- data.table(data_all, key =c("pep_id","lon", "lat", "alt", "sp","year"))
dt2 <- data.table(fix,  key =c("pep_id","lon", "lat", "alt", "sp","year"))
data_all <- dt1[dt2,allow.cartesian=TRUE]
data_all <- na.omit(data_all)


####fluxdata #####
fluxn <- fread('fluxData.csv')
group <- fread('IGBP_data.csv') #IGBP data
flux0 <- fluxn[, c('site', 'lon.x', 'lat.x', 'X.x', 'SSA_GPP', 'SSA_NE_CUT','SW_IN_F_MDS', 
                   'TA_F_MDS', 'VPD_F_MDS', 'P_F', 'WS_F', 'CO2_F_MDS',
                   'SWC_F_MDS_1','TS_F_MDS_1', 'output_dem', 'type.y', 'sos','eos')]
flux1 <- plyr::join(flux0, group) %>% 
  subset(., IGBP%in%c('DNF', 'DBF', 'ENF', 'EBF'))

flux_cli <- flux1 %>% 
  dplyr::select(., site,lon.x,lat.x,output_dem,
                SSA_GPP,SSA_NE_CUT,TA_F_MDS,VPD_F_MDS,P_F,WS_F,SW_IN_F_MDS,
                CO2_F_MDS,SWC_F_MDS_1,type.y,IGBP,year,month,doy, eos) %>% 
  mutate(., year = as.integer(year)+1)

flux_phe <- flux1 %>% 
  dplyr::select(., site,lon.x,lat.x,output_dem,type.y,IGBP,year,sos) %>% 
  unique()

##select vegetation type of Forest 
flux0 <- plyr::join(flux_phe, flux_cli) %>% 
  subset(., sos>0) 

flux_mat <- flux0 %>% 
  ddply(., .(site, year,lon.x,lat.x,output_dem, type.y,IGBP,sos, eos), summarise, 
        magpp = mean(SSA_GPP, na.rm = T), manee = mean(SSA_NE_CUT, na.rm = T),
        maradi = mean(SW_IN_F_MDS), mat = mean(TA_F_MDS, na.rm = T), marain = mean(P_F, na.rm = T), 
        mavpd = mean(TA_F_MDS, na.rm = T), mawinds = mean(WS_F, na.rm = T),
        masoilw = mean(SWC_F_MDS_1), maco2 = mean(CO2_F_MDS, na.rm = T))

flux_grow <- flux0 %>% 
  subset(., month %in%c(5:9)) %>% 
  ddply(., .(site, year,lon.x,lat.x,output_dem, type.y,IGBP,sos, eos), summarise, 
        growgpp = mean(SSA_GPP, na.rm = T), gppmax = max(SSA_GPP, na.rm = T),
        grownee = mean(SSA_NE_CUT, na.rm = T),
        growradi = mean(SW_IN_F_MDS), growt = mean(TA_F_MDS, na.rm = T), growrain = mean(P_F, na.rm = T), 
        growvpd = mean(TA_F_MDS, na.rm = T), growwinds = mean(WS_F, na.rm = T),
        growsoilw = mean(SWC_F_MDS_1),growco2 = mean(CO2_F_MDS, na.rm = T))


flux11 <- plyr::join(flux_mat, flux_grow, type = 'left') %>% 
  ddply(., .(site), mutate, vy =length(unique(year)))






